@@ -208,8 +208,6 @@ class TweepyApi(BaseTweepyApi, ApiAdapter):
     @include_entities
     def get_home_timeline(self, **kwargs):
         tweets = self._api.home_timeline(**kwargs)
-        retweets = self._api.retweeted_to_me(**kwargs)
-        tweets.extend(retweets)
         return tweets
 
     @to_status
@@ -221,16 +219,12 @@ class TweepyApi(BaseTweepyApi, ApiAdapter):
     @include_entities
     def get_own_timeline(self, **kwargs):
         me = self.verify_credentials()
-        tweets = self._api.user_timeline(screen_name=me.screen_name,
-                                         **kwargs)
-        retweets = self._api.retweeted_by_me(**kwargs)
-        tweets.extend(retweets)
-        return tweets
+        return self._api.user_timeline(screen_name=me.screen_name, **kwargs)
 
     @to_status
     @include_entities
     def get_mentions(self, **kwargs):
-        return self._api.mentions(**kwargs)
+        return self._api.mentions_timeline(**kwargs)
 
     @to_status
     @include_entities
@@ -346,11 +340,11 @@ class TweepyApi(BaseTweepyApi, ApiAdapter):
 
     @to_list
     def get_lists(self, screen_name):
-        return self._api.lists(screen_name)
+        return self._api.lists_all(screen_name)
 
     @to_list
     def get_own_lists(self):
-        return self._api.lists()
+        return self._api.lists_all()
 
     @to_list
     def get_list_memberships(self):
@@ -370,11 +364,6 @@ class TweepyApi(BaseTweepyApi, ApiAdapter):
         owner = a_list.owner.screen_name
         return self._api.list_members(owner=owner, slug=a_list.slug)
 
-    def is_list_member(self, user, a_list):
-        return bool(self._api.is_list_member(owner=user.screen_name,
-                                             slug=a_list.slug,
-                                             user_id=user.id,))
-
     @to_list
     def subscribe_to_list(self, a_list):
         owner = a_list.owner
@@ -386,8 +375,3 @@ class TweepyApi(BaseTweepyApi, ApiAdapter):
         owner = a_list.owner
         return self._api.list_subscribers(owner=owner.screen_name,
                                           slug=a_list.slug,)
-
-    def is_list_subscriber(self, user, a_list):
-        return bool(self._api.is_subscribed_list(owner=user.screen_name,
-                                                 slug=a_list.slug,
-                                                 user_id=user.id,))
