@@ -332,7 +332,9 @@ PALETTE = [
 
 STYLES = {
     # TODO: make time string configurable
-    'header_template': ' {username}{retweeted}{retweeter} - {time}{reply} {retweet_count} ',
+    'reply_indicator': u'✉',
+    'retweet_indicator': u'♻',
+    'header_template': ' {username}{retweeted}{retweeter} - {time}{reply}{retweet_count} ',
     'dm_template': ' {sender_screen_name} => {recipient_screen_name} - {time} ',
     'tab_template': '{timeline_name} [{unread}]',
     'box_around_status': True,
