@@ -9,7 +9,12 @@ import time
 from re import sub
 from bisect import insort
 from calendar import timegm
-from functools import total_ordering
+
+try:
+    from functools import total_ordering
+except ImportError:
+    from turses.utils import total_ordering
+
 from htmlentitydefs import entitydefs
 
 from turses.meta import (ActiveList, UnsortedActiveList, Updatable, Observable,
@@ -184,7 +189,10 @@ class TimelineList(UnsortedActiveList, Observable):
         return self.timelines.__iter__()
 
     def __len__(self):
-        return self.timelines.__len__()
+        return len(self.timelines)
+
+    def __getitem__(self, key):
+        return self.timelines[key]
 
     # from `UnsortedActiveList`
 
@@ -362,8 +370,8 @@ class Timeline(ActiveList, Updatable):
     def __iter__(self):
         return self.statuses.__iter__()
 
-    def __getitem__(self, i):
-        return self.statuses[i]
+    def __getitem__(self, key):
+        return self.statuses[key]
 
     # from `ActiveList`
 
@@ -443,16 +451,18 @@ class Status(object):
                  created_at,
                  user,
                  text,
+                 author='',
+                 entities=None,
+                 # reply
                  is_reply=False,
-                 is_retweet=False,
-                 is_favorite=False,
-                 # for replies
                  in_reply_to_user='',
-                 # for retweets
+                 in_reply_to_status_id=None,
+                 # retweet
+                 is_retweet=False,
                  retweeted_status=None,
                  retweet_count=0,
-                 author='',
-                 entities=None):
+                 # favorite
+                 is_favorite=False,):
         self.id = id
         self.created_at = created_at
         self.user = user
